@@ -1,17 +1,18 @@
 import shutil
 from sqlalchemy.sql import text
+from FreeTAKServer.model.SQLAlchemy.Root import Base
 
 class TableController:
     # default constructor  def __init__(self):
     def __init__(self):
-        self.table = None
+        self.table: Base = object  # all inheriting methods MUST implement this variable
 
 
     def delete(self, session, query):
         # this function removes a row from the datapackages table based on the uid
         session.query(self.table).filter(text(query)).delete(synchronize_session='fetch')
         session.commit()
-
+        return 1
 
     def create(self, session, **args):
         # this function adds a new row to the datapackages table
@@ -32,4 +33,4 @@ class TableController:
         for dp in DataPackages:
             for column, value in column_value.items():
                 setattr(dp, column, value)
-        session.commit()
\ No newline at end of file
+        session.commit()
