@@ -1,16 +1,19 @@
 from .DataPackageServer import FlaskFunctions, Path, dp_directory, os, app, eventlet, const
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
-loggingConstants = LoggingConstants()
-logger = CreateLoggerController("TCPDataPackageServer").getLogger()
+from FreeTAKServer.controllers.configuration.DataPackageServerConstants import DataPackageServerConstants
+
+loggingConstants = LoggingConstants(log_name="FTS-TCP_DataPackage_Service")
+logger = CreateLoggerController("FTS-TCP_DataPackage_Service", logging_constants=loggingConstants).getLogger()
 
 class TCPDataPackageService(FlaskFunctions):
-    def startup(self, ip, port):
+    def startup(self, ip, port, pipe):
         try:
             from eventlet import wsgi
-            global IP, HTTPPORT
+            global IP, HTTPPORT, PIPE
             IP = ip
             HTTPPORT = port
+            PIPE = pipe
             # Make sure the data package directory exists
             if not Path(dp_directory).exists():
                 app.logger.info(f"Creating directory at {str(dp_directory)}")
@@ -20,7 +23,8 @@ class TCPDataPackageService(FlaskFunctions):
             print(HTTPPORT)
             super().setHTTPPORT(HTTPPORT)
             super().setIP(IP)
-            wsgi.server(eventlet.listen((IP, HTTPPORT)), app)
+            super().setPIPE(PIPE)
+            wsgi.server(eventlet.listen((DataPackageServerConstants().IP, HTTPPORT)), app)
 
 
         except Exception as e:
