@@ -1,6 +1,6 @@
 class ToolVariables:
     @classmethod
-    def CreateExCheckTemplate(cls):
-        cls.INTAG = None
+    def ExcheckUpdate(cls):
+        cls.INTAG = "ExCheck"
         return cls
 
